@@ -18,13 +18,14 @@ from .base import Relation
 from .conf import DatabaseConnection
 from .conf import load_config
 from .conf import DATABASES
+from .enginemanager import AsyncEngineManager
 from .enginemanager import EngineManager
 from .repository import RelationalDatabaseRepository
 from .repository import Repository
 from . import query
 
 ENGINES = EngineManager()
-ASYNC_ENGINES = EngineManager()
+ASYNC_ENGINES = AsyncEngineManager()
 
 
 def awaitservices(max_retries=60, interval=1, databases=None):
