@@ -1,5 +1,6 @@
 """Specifies entrypoint operations for Unimatrix integration."""
-from . import destroy_engines
+from . import ENGINES
+from . import ASYNC_ENGINES
 
 
 # Provides a hint to unimatrix.runtime.boot.shutdown()
@@ -7,5 +8,6 @@ from . import destroy_engines
 WEIGHT = 1000
 
 
-def on_teardown(*args, **kwargs):
-    destroy_engines()
+async def on_teardown(*args, **kwargs):
+    ENGINES.destroy()
+    await ASYNC_ENGINES.destroy()
