@@ -50,3 +50,12 @@ class EngineManager:
 
     def __iter__(self):
         return iter(self.engines)
+
+
+class AsyncEngineManager(EngineManager):
+
+    async def destroy(self, loop=None):
+        """Destroys all known engines."""
+        for name in list(dict.keys(self.engines)):
+            engine = self.engines.pop(name)
+            await engine.dispose()
