@@ -132,6 +132,21 @@ class BaseDeclarativeQuery(NamedQuery):
     process the result as an SQLAlchemy declarative model.
     """
 
+    def build(self, *args, **kwargs):
+        if not self.predicate:
+            # Query a Declarative SQLAlchemy model. If no predicate was defined,
+            # we assume that the parameter names match the column names.
+            query = select(self.model)
+            for colname, value in dict.items(self._params):
+                if not hasattr(self.model, colname):
+                    raise NotImplementedError(
+                        "Parameter names must match column names."
+                    )
+                query = query.filter(getattr(self.model, colname)==value)
+        else:
+            query = super().build(*args, **kwargs)
+        return query
+
     def process_result(self, result):
         return result.scalars()
 
@@ -180,7 +195,14 @@ class Exists(NamedQuery):
         return lambda self, q: bool(q)
 
     def query_factory(self, relation):
-        return exists(1)
+        q = exists(1)
+
+        # No predicate, model defined.
+        if not self.predicate and self.model:
+            q = exists(1)
+            for colname, value in dict.items(self._params):
+                q = q.where(getattr(self.model, colname) == value)
+        return q
 
     def _build(self, *args, **kwargs):
         q = super()._build(*args, **kwargs)
