@@ -2,6 +2,7 @@
 from sqlalchemy import select
 
 from unimatrix.ext.orm import async_session
+from unimatrix.ext.orm import destroy_engines
 from unimatrix.ext.orm.testing import AsyncSessionTestCase
 from .orm import Foo
 
@@ -20,7 +21,10 @@ class TestAsyncSessionTestCase(AsyncSessionTestCase):
         super().setUp()
 
     def tearDown(self):
-        super().tearDown(close_loop=False)
-        session = async_session()
-        result = self.execute_query(session, select(Foo))
-        self.assertEqual(len(list(result)), 0)
+        super().tearDown(destroy=False)
+        try:
+            session = async_session()
+            result = self.execute_query(session, select(Foo))
+            self.assertEqual(len(list(result)), 0)
+        finally:
+            destroy_engines()
